@@ -417,6 +417,23 @@ void TaskWorkerPool::_update_tablet_meta_worker_thread_callback() {
                 continue;
             }
             bool need_to_save = false;
+            if (tablet_meta_info.__isset.partition_id) {
+                // for fix partition_id = 0
+                LOG(WARNING) << "change be tablet id: " << tablet->tablet_meta()->tablet_id()
+                             << "partition id from : " << tablet->tablet_meta()->partition_id()
+                             << " to : " << tablet_meta_info.partition_id;
+                auto succ = StorageEngine::instance()->tablet_manager()->update_tablet_partition_id(
+                        tablet_meta_info.partition_id, tablet->tablet_meta()->tablet_id());
+                if (!succ) {
+                    std::string err_msg = fmt::format(
+                            "change be tablet id : {} partition_id : {} failed",
+                            tablet->tablet_meta()->tablet_id(), tablet_meta_info.partition_id);
+                    LOG(WARNING) << err_msg;
+                    status = Status::InvalidArgument(err_msg);
+                    continue;
+                }
+                need_to_save = true;
+            }
             if (tablet_meta_info.__isset.storage_policy_id) {
                 tablet->tablet_meta()->set_storage_policy_id(tablet_meta_info.storage_policy_id);
                 need_to_save = true;
