@@ -310,16 +310,6 @@ public:
                 condition.__set_condition_op("match_phrase_prefix");
             } else if (value.first == MatchType::MATCH_REGEXP) {
                 condition.__set_condition_op("match_regexp");
-            } else if (value.first == MatchType::MATCH_ELEMENT_EQ) {
-                condition.__set_condition_op("match_element_eq");
-            } else if (value.first == MatchType::MATCH_ELEMENT_LT) {
-                condition.__set_condition_op("match_element_lt");
-            } else if (value.first == MatchType::MATCH_ELEMENT_GT) {
-                condition.__set_condition_op("match_element_gt");
-            } else if (value.first == MatchType::MATCH_ELEMENT_LE) {
-                condition.__set_condition_op("match_element_le");
-            } else if (value.first == MatchType::MATCH_ELEMENT_GE) {
-                condition.__set_condition_op("match_element_ge");
             }
             condition.condition_values.push_back(
                     cast_to_string<primitive_type, CppType>(value.second, _scale));
@@ -695,14 +685,15 @@ bool ColumnValueRange<primitive_type>::convert_to_close_range(
         bool is_empty = false;
 
         if (!is_begin_include()) {
-            if (_low_value == TYPE_MIN) {
+            if (_low_value == TYPE_MAX) {
                 is_empty = true;
             } else {
                 ++_low_value;
             }
         }
+
         if (!is_end_include()) {
-            if (_high_value == TYPE_MAX) {
+            if (_high_value == TYPE_MIN) {
                 is_empty = true;
             } else {
                 --_high_value;
