@@ -129,11 +129,6 @@ DeltaWriter::~DeltaWriter() {
         _calc_delete_bitmap_token->cancel();
     }
 
-    if (_tablet != nullptr) {
-        _tablet->data_dir()->remove_pending_ids(ROWSET_ID_PREFIX +
-                                                _rowset_writer->rowset_id().to_string());
-    }
-
     _mem_table.reset();
 }
 
@@ -194,9 +189,9 @@ Status DeltaWriter::init() {
     }
 
     {
-        std::shared_lock base_migration_rlock(_tablet->get_migration_lock(), std::try_to_lock);
-        if (!base_migration_rlock.owns_lock()) {
-            return Status::Error<TRY_LOCK_FAILED>("get lock failed");
+        std::shared_lock base_migration_rlock(_tablet->get_migration_lock(), std::defer_lock);
+        if (!base_migration_rlock.try_lock_for(std::chrono::milliseconds(30))) {
+            return Status::Error<TRY_LOCK_FAILED>("try migration lock failed");
         }
         std::lock_guard<std::mutex> push_lock(_tablet->get_push_lock());
         RETURN_IF_ERROR(_storage_engine->txn_manager()->prepare_txn(_req.partition_id, _tablet,
