@@ -99,13 +99,6 @@ bool InvertedIndexReader::_is_match_query(InvertedIndexQueryType query_type) {
             query_type == InvertedIndexQueryType::MATCH_REGEXP_QUERY);
 }
 
-bool InvertedIndexReader::indexExists(io::Path& index_file_path) {
-    // SCOPED_RAW_TIMER(&stats->inverted_index_query_file_exists_timer);
-    bool exists = false;
-    RETURN_IF_ERROR(_fs->exists(index_file_path, &exists));
-    return exists;
-}
-
 std::unique_ptr<lucene::analysis::Analyzer> InvertedIndexReader::create_analyzer(
         InvertedIndexCtx* inverted_index_ctx) {
     std::unique_ptr<lucene::analysis::Analyzer> analyzer;
@@ -210,21 +203,18 @@ Status InvertedIndexReader::read_null_bitmap(OlapReaderStatistics* stats,
             return Status::OK();
         }
 
-        bool exists = false;
-        {
-            SCOPED_RAW_TIMER(&stats->inverted_index_query_file_exists_timer);
-            RETURN_IF_ERROR(_fs->exists(index_file_path, &exists));
-        }
-        if (!exists) {
-            LOG(WARNING) << "inverted index: " << index_file_path.native() << " not exist.";
-            return Status::Error<ErrorCode::INVERTED_INDEX_FILE_NOT_FOUND>(
-                    "inverted index path: {} not exist.", index_file_path.native());
-        }
-
         if (!dir) {
-            dir = new DorisCompoundReader(
-                    DorisCompoundDirectoryFactory::getDirectory(_fs, index_dir.c_str()),
-                    index_file_name.c_str(), config::inverted_index_read_buffer_size);
+            try {
+                dir = new DorisCompoundReader(
+                        DorisCompoundDirectoryFactory::getDirectory(_fs, index_dir.c_str()),
+                        index_file_name.c_str(), config::inverted_index_read_buffer_size);
+            } catch (CLuceneError& err) {
+                if (err.number() == CL_ERR_FileNotFound) {
+                    return Status::Error<ErrorCode::INVERTED_INDEX_FILE_NOT_FOUND>(
+                            "inverted index path: {} not exist.", index_file_path.native());
+                }
+                throw err;
+            }
             owned_dir = true;
         }
 
@@ -639,8 +629,18 @@ Status StringTypeInvertedIndexReader::query(OlapReaderStatistics* stats,
 
     const StringRef* search_query = reinterpret_cast<const StringRef*>(query_value);
     auto act_len = strnlen(search_query->data, search_query->size);
+
+    // If the written value exceeds ignore_above, it will be written as null.
+    // The queried value exceeds ignore_above means the written value cannot be found.
+    // The query needs to be downgraded to read from the segment file.
+    if (int ignore_above =
+                std::stoi(get_parser_ignore_above_value_from_properties(_index_meta.properties()));
+        act_len > ignore_above) {
+        return Status::Error<ErrorCode::INVERTED_INDEX_EVALUATE_SKIPPED>(
+                "query value is too long, evaluate skipped.");
+    }
+
     std::string search_str(search_query->data, act_len);
-    // std::string search_str = reinterpret_cast<const StringRef*>(query_value)->to_string();
     VLOG_DEBUG << "begin to query the inverted index from clucene"
                << ", column_name: " << column_name << ", search_str: " << search_str;
     std::wstring column_name_ws = StringUtil::string_to_wstring(column_name);
@@ -763,17 +763,18 @@ BkdIndexReader::BkdIndexReader(io::FileSystemSPtr fs, const std::string& path,
     auto index_dir = io_path.parent_path();
     auto index_file_name = InvertedIndexDescriptor::get_index_file_name(io_path.filename(),
                                                                         index_meta->index_id());
-
-    // check index file existence
     auto index_file = index_dir / index_file_name;
-    if (!indexExists(index_file)) {
-        LOG(WARNING) << "bkd index: " << index_file.string() << " not exist.";
-        return;
-    }
     _file_full_path = index_file;
-    _compoundReader = std::make_unique<DorisCompoundReader>(
-            DorisCompoundDirectoryFactory::getDirectory(fs, index_dir.c_str()),
-            index_file_name.c_str(), config::inverted_index_read_buffer_size);
+    try {
+        _compoundReader = std::make_unique<DorisCompoundReader>(
+                DorisCompoundDirectoryFactory::getDirectory(fs, index_dir.c_str()),
+                index_file_name.c_str(), config::inverted_index_read_buffer_size);
+    } catch (CLuceneError& err) {
+        if (err.number() == CL_ERR_FileNotFound) {
+            LOG(WARNING) << "bkd index: " << index_file.string() << " not exist.";
+            return;
+        }
+    }
 }
 
 Status BkdIndexReader::new_iterator(OlapReaderStatistics* stats, RuntimeState* runtime_state,
