@@ -93,7 +93,7 @@ Status SnapshotLoader::init(TStorageBackendType::type type, const std::string& l
         RETURN_IF_ERROR(io::BrokerFileSystem::create(_broker_addr, _prop, &fs));
         _remote_fs = std::move(fs);
     } else {
-        return Status::InternalError("Unknown storage tpye: {}", type);
+        return Status::InternalError("Unknown storage type: {}", type);
     }
     return Status::OK();
 }
