@@ -103,6 +103,7 @@ void _ingest_binlog(IngestBinlogArg* arg) {
     auto& request = arg->request;
 
     TStatus tstatus;
+    std::vector<std::string> download_success_files;
     Defer defer {[=, &tstatus, ingest_binlog_tstatus = arg->tstatus]() {
         LOG(INFO) << "ingest binlog. result: " << apache::thrift::ThriftDebugString(tstatus);
         if (tstatus.status_code != TStatusCode::OK) {
@@ -110,6 +111,15 @@ void _ingest_binlog(IngestBinlogArg* arg) {
             StorageEngine::instance()->txn_manager()->abort_txn(
                     partition_id, txn_id, local_tablet_id, local_tablet->schema_hash(),
                     local_tablet_uid);
+            // delete all successfully downloaded files
+            LOG(WARNING) << "will delete downloaded success files due to error " << tstatus;
+            std::vector<io::Path> paths;
+            for (const auto& file : download_success_files) {
+                paths.emplace_back(file);
+                LOG(WARNING) << "will delete downloaded success file " << file << " due to error";
+            }
+            static_cast<void>(io::global_local_filesystem()->batch_delete(paths));
+            LOG(WARNING) << "done delete downloaded success files due to error " << tstatus;
         }
 
         if (ingest_binlog_tstatus) {
@@ -146,10 +156,25 @@ void _ingest_binlog(IngestBinlogArg* arg) {
     }
 
     std::vector<std::string> binlog_info_parts = strings::Split(binlog_info, ":");
-    // TODO(Drogon): check binlog info content is right
-    DCHECK(binlog_info_parts.size() == 2);
-    const std::string& remote_rowset_id = binlog_info_parts[0];
-    int64_t num_segments = std::stoll(binlog_info_parts[1]);
+    if (binlog_info_parts.size() != 2) {
+        status = Status::RuntimeError("failed to parse binlog info into 2 parts: {}", binlog_info);
+        LOG(WARNING) << "failed to get binlog info from " << get_binlog_info_url
+                     << ", status=" << status.to_string();
+        status.to_thrift(&tstatus);
+        return;
+    }
+    std::string remote_rowset_id = std::move(binlog_info_parts[0]);
+    int64_t num_segments = -1;
+    try {
+        num_segments = std::stoll(binlog_info_parts[1]);
+    } catch (std::exception& e) {
+        status = Status::RuntimeError("failed to parse num segments from binlog info {}: {}",
+                                      binlog_info, e.what());
+        LOG(WARNING) << "failed to get binlog info from " << get_binlog_info_url
+                     << ", status=" << status;
+        status.to_thrift(&tstatus);
+        return;
+    }
 
     // Step 4: get rowset meta
     auto get_rowset_meta_url = fmt::format(
@@ -224,7 +249,8 @@ void _ingest_binlog(IngestBinlogArg* arg) {
     }
 
     // Step 5.2: check data capacity
-    uint64_t total_size = std::accumulate(segment_file_sizes.begin(), segment_file_sizes.end(), 0);
+    uint64_t total_size = std::accumulate(segment_file_sizes.begin(), segment_file_sizes.end(),
+                                          0ULL); // NOLINT(bugprone-fold-init-type)
     if (!local_tablet->can_add_binlog(total_size)) {
         LOG(WARNING) << "failed to add binlog, no enough space, total_size=" << total_size
                      << ", tablet=" << local_tablet->tablet_id();
@@ -249,10 +275,11 @@ void _ingest_binlog(IngestBinlogArg* arg) {
         LOG(INFO) << fmt::format("download segment file from {} to {}", get_segment_file_url,
                                  local_segment_path);
         auto get_segment_file_cb = [&get_segment_file_url, &local_segment_path, segment_file_size,
-                                    estimate_timeout](HttpClient* client) {
+                                    estimate_timeout, &download_success_files](HttpClient* client) {
             RETURN_IF_ERROR(client->init(get_segment_file_url));
             client->set_timeout_ms(estimate_timeout * 1000);
             RETURN_IF_ERROR(client->download(local_segment_path));
+            download_success_files.push_back(local_segment_path);
 
             std::error_code ec;
             // Check file length
@@ -282,8 +309,116 @@ void _ingest_binlog(IngestBinlogArg* arg) {
         }
     }
 
-    // Step 6: create rowset && calculate delete bitmap && commit
-    // Step 6.1: create rowset
+    // Step 6: get all segment index files
+    // Step 6.1: get all segment index files size
+    std::vector<std::string> segment_index_file_urls;
+    std::vector<uint64_t> segment_index_file_sizes;
+    std::vector<std::string> segment_index_file_names;
+    auto tablet_schema = rowset_meta->tablet_schema();
+    for (const auto& index : tablet_schema->indexes()) {
+        if (index.index_type() != IndexType::INVERTED) {
+            continue;
+        }
+        auto index_id = index.index_id();
+        for (int64_t segment_index = 0; segment_index < num_segments; ++segment_index) {
+            auto get_segment_index_file_size_url = fmt::format(
+                    "{}?method={}&tablet_id={}&rowset_id={}&segment_index={}&segment_index_id={"
+                    "}",
+                    binlog_api_url, "get_segment_index_file", request.remote_tablet_id,
+                    remote_rowset_id, segment_index, index_id);
+            uint64_t segment_index_file_size;
+            auto get_segment_index_file_size_cb = [&get_segment_index_file_size_url,
+                                                   &segment_index_file_size](HttpClient* client) {
+                RETURN_IF_ERROR(client->init(get_segment_index_file_size_url));
+                client->set_timeout_ms(kMaxTimeoutMs);
+                RETURN_IF_ERROR(client->head());
+                return client->get_content_length(&segment_index_file_size);
+            };
+            auto index_file = InvertedIndexDescriptor::inverted_index_file_path(
+                    local_tablet->tablet_path(), rowset_meta->rowset_id(), segment_index, index_id);
+            segment_index_file_names.push_back(index_file);
+
+            status = HttpClient::execute_with_retry(max_retry, 1, get_segment_index_file_size_cb);
+            if (!status.ok()) {
+                LOG(WARNING) << "failed to get segment file size from "
+                             << get_segment_index_file_size_url
+                             << ", status=" << status.to_string();
+                status.to_thrift(&tstatus);
+                return;
+            }
+
+            segment_index_file_sizes.push_back(segment_index_file_size);
+            segment_index_file_urls.push_back(std::move(get_segment_index_file_size_url));
+        }
+    }
+
+    // Step 6.2: check data capacity
+    uint64_t total_index_size =
+            std::accumulate(segment_index_file_sizes.begin(), segment_index_file_sizes.end(),
+                            0ULL); // NOLINT(bugprone-fold-init-type)
+    if (!local_tablet->can_add_binlog(total_index_size)) {
+        LOG(WARNING) << "failed to add binlog, no enough space, total_index_size="
+                     << total_index_size << ", tablet=" << local_tablet->tablet_id();
+        status = Status::InternalError("no enough space");
+        status.to_thrift(&tstatus);
+        return;
+    }
+
+    // Step 6.3: get all segment index files
+    DCHECK(segment_index_file_sizes.size() == segment_index_file_names.size());
+    DCHECK(segment_index_file_names.size() == segment_index_file_urls.size());
+    for (int64_t i = 0; i < segment_index_file_urls.size(); ++i) {
+        auto segment_index_file_size = segment_index_file_sizes[i];
+        auto get_segment_index_file_url = segment_index_file_urls[i];
+
+        uint64_t estimate_timeout =
+                segment_index_file_size / config::download_low_speed_limit_kbps / 1024;
+        if (estimate_timeout < config::download_low_speed_time) {
+            estimate_timeout = config::download_low_speed_time;
+        }
+
+        auto local_segment_index_path = segment_index_file_names[i];
+        LOG(INFO) << fmt::format("download segment index file from {} to {}",
+                                 get_segment_index_file_url, local_segment_index_path);
+        auto get_segment_index_file_cb = [&get_segment_index_file_url, &local_segment_index_path,
+                                          segment_index_file_size, estimate_timeout,
+                                          &download_success_files](HttpClient* client) {
+            RETURN_IF_ERROR(client->init(get_segment_index_file_url));
+            client->set_timeout_ms(estimate_timeout * 1000);
+            RETURN_IF_ERROR(client->download(local_segment_index_path));
+            download_success_files.push_back(local_segment_index_path);
+
+            std::error_code ec;
+            // Check file length
+            uint64_t local_index_file_size =
+                    std::filesystem::file_size(local_segment_index_path, ec);
+            if (ec) {
+                LOG(WARNING) << "download index file error" << ec.message();
+                return Status::IOError("can't retrive file_size of {}, due to {}",
+                                       local_segment_index_path, ec.message());
+            }
+            if (local_index_file_size != segment_index_file_size) {
+                LOG(WARNING) << "download index file length error"
+                             << ", get_segment_index_file_url=" << get_segment_index_file_url
+                             << ", index_file_size=" << segment_index_file_size
+                             << ", local_index_file_size=" << local_index_file_size;
+                return Status::InternalError("downloaded index file size is not equal");
+            }
+            return io::global_local_filesystem()->permission(local_segment_index_path,
+                                                             io::LocalFileSystem::PERMS_OWNER_RW);
+        };
+
+        status = HttpClient::execute_with_retry(max_retry, 1, get_segment_index_file_cb);
+        if (!status.ok()) {
+            LOG(WARNING) << "failed to get segment index file from " << get_segment_index_file_url
+                         << ", status=" << status.to_string();
+            status.to_thrift(&tstatus);
+            return;
+        }
+    }
+
+    // Step 7: create rowset && calculate delete bitmap && commit
+    // Step 7.1: create rowset
     RowsetSharedPtr rowset;
     status = RowsetFactory::create_rowset(local_tablet->tablet_schema(),
                                           local_tablet->tablet_path(), rowset_meta, &rowset);
@@ -298,7 +433,7 @@ void _ingest_binlog(IngestBinlogArg* arg) {
         return;
     }
 
-    // Step 6.2 calculate delete bitmap before commit
+    // Step 7.2 calculate delete bitmap before commit
     auto calc_delete_bitmap_token =
             StorageEngine::instance()->calc_delete_bitmap_executor()->create_token();
     DeleteBitmapPtr delete_bitmap = std::make_shared<DeleteBitmap>(local_tablet_id);
@@ -334,7 +469,7 @@ void _ingest_binlog(IngestBinlogArg* arg) {
         static_cast<void>(calc_delete_bitmap_token->wait());
     }
 
-    // Step 6.3: commit txn
+    // Step 7.3: commit txn
     Status commit_txn_status = StorageEngine::instance()->txn_manager()->commit_txn(
             local_tablet->data_dir()->get_meta(), rowset_meta->partition_id(),
             rowset_meta->txn_id(), rowset_meta->tablet_id(), local_tablet->schema_hash(),
