@@ -499,14 +499,14 @@ void NewOlapScanner::_update_realtime_counters() {
     _tablet_reader->mutable_stats()->raw_rows_read = 0;
 }
 
-void NewOlapScanner::_update_counters_before_close() {
+void NewOlapScanner::_collect_profile_before_close() {
     //  Please don't directly enable the profile here, we need to set QueryStatistics using the counter inside.
     if (_has_updated_counter) {
         return;
     }
     _has_updated_counter = true;
 
-    VScanner::_update_counters_before_close();
+    VScanner::_collect_profile_before_close();
 
     // Update counters for NewOlapScanner
     NewOlapScanNode* olap_parent = (NewOlapScanNode*)_parent;
@@ -587,8 +587,6 @@ void NewOlapScanner::_update_counters_before_close() {
     COUNTER_UPDATE(olap_parent->_inverted_index_query_cache_miss_counter,
                    stats.inverted_index_query_cache_miss);
     COUNTER_UPDATE(olap_parent->_inverted_index_query_timer, stats.inverted_index_query_timer);
-    COUNTER_UPDATE(olap_parent->_inverted_index_query_file_exists_timer,
-                   stats.inverted_index_query_file_exists_timer);
     COUNTER_UPDATE(olap_parent->_inverted_index_query_null_bitmap_timer,
                    stats.inverted_index_query_null_bitmap_timer);
     COUNTER_UPDATE(olap_parent->_inverted_index_query_bitmap_copy_timer,
