@@ -20,16 +20,8 @@
 
 #pragma once
 
-#include <utility>
-
-#include "vec/columns/column_string.h"
-#include "vec/columns/column_vector.h"
-#include "vec/common/bit_cast.h"
 #include "vec/common/hash_table/hash.h"
-#include "vec/data_types/data_type.h"
-#include "vec/data_types/data_type_number.h"
-#include "vec/functions/function.h"
-#include "vec/functions/function_helpers.h"
+#include "vec/core/types.h"
 
 namespace doris::vectorized {
 
