@@ -139,10 +139,7 @@ public:
                          size_t input_rows_count, const ColumnString* string_col,
                          InvertedIndexCtx* inverted_index_ctx,
                          const ColumnArray::Offsets64* array_offsets,
-                         ColumnUInt8::Container& result) override {
-        return Status::Error<ErrorCode::INVERTED_INDEX_NOT_SUPPORTED>(
-                "FunctionMatchPhrasePrefix not support execute_match");
-    }
+                         ColumnUInt8::Container& result) override;
 };
 
 class FunctionMatchRegexp : public FunctionMatchBase {
@@ -156,10 +153,7 @@ public:
                          size_t input_rows_count, const ColumnString* string_col,
                          InvertedIndexCtx* inverted_index_ctx,
                          const ColumnArray::Offsets64* array_offsets,
-                         ColumnUInt8::Container& result) override {
-        return Status::Error<ErrorCode::INVERTED_INDEX_NOT_SUPPORTED>(
-                "FunctionMatchRegexp not support execute_match");
-    }
+                         ColumnUInt8::Container& result) override;
 };
 
 } // namespace doris::vectorized
