@@ -34,6 +34,7 @@ import org.apache.doris.common.ErrorCode;
 import org.apache.doris.common.ErrorReport;
 import org.apache.doris.common.UserException;
 import org.apache.doris.common.util.Util;
+import org.apache.doris.datasource.CatalogIf;
 import org.apache.doris.mysql.privilege.PrivPredicate;
 import org.apache.doris.qe.ConnectContext;
 import org.apache.doris.qe.SessionVariable;
@@ -306,9 +307,9 @@ public class DeleteStmt extends DdlStmt {
     private void checkDeleteConditions() throws AnalysisException {
         // check condition column is key column and condition value
         // Here we use "getFullSchema()" to get all columns including VISIBLE and SHADOW columns
-
+        CatalogIf catalog = getCatalog();
         // we ensure the db and table exists.
-        Database db = (Database) Env.getCurrentEnv().getCurrentCatalog().getDb(getDbName()).get();
+        Database db = (Database) catalog.getDb(getDbName()).get();
         OlapTable table = ((OlapTable) db.getTable(getTableName()).get());
 
         Map<String, Column> nameToColumn = Maps.newTreeMap(String.CASE_INSENSITIVE_ORDER);
@@ -437,6 +438,15 @@ public class DeleteStmt extends DdlStmt {
         return slotRef;
     }
 
+    private CatalogIf getCatalog() {
+        Env env = Env.getCurrentEnv();
+        if (null == tableName.getCtl()) {
+            return env.getCurrentCatalog();
+        } else {
+            return env.getCatalogMgr().getCatalog(tableName.getCtl());
+        }
+    }
+
     @Override
     public String toSql() {
         StringBuilder sb = new StringBuilder();
