@@ -254,6 +254,8 @@ public class ModifyTablePropertiesClause extends AlterTableClause {
             }
             this.needTableStable = false;
             this.opType = AlterOpType.MODIFY_TABLE_PROPERTY_SYNC;
+        } else if (properties.containsKey(PropertyAnalyzer.PROPERTIES_ESTIMATE_PARTITION_SIZE)) {
+            throw new AnalysisException("You can not modify estimate partition size");
         } else {
             throw new AnalysisException("Unknown table property: " + properties.keySet());
         }
