@@ -18,17 +18,24 @@
 package org.apache.doris.binlog;
 
 import org.apache.doris.catalog.BinlogConfig;
+import org.apache.doris.catalog.Database;
+import org.apache.doris.catalog.OlapTable;
+import org.apache.doris.catalog.Table;
 import org.apache.doris.common.Pair;
+import org.apache.doris.common.proc.BaseProcResult;
 import org.apache.doris.thrift.TBinlog;
 import org.apache.doris.thrift.TBinlogType;
 import org.apache.doris.thrift.TStatus;
 
+import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 
+import java.util.ArrayList;
 import java.util.Comparator;
 import java.util.Iterator;
+import java.util.List;
 import java.util.TreeSet;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
@@ -37,15 +44,23 @@ public class TableBinlog {
 
     private long dbId;
     private long tableId;
+    private long binlogSize;
     private ReentrantReadWriteLock lock;
     private TreeSet<TBinlog> binlogs;
+
+    // Pair(commitSeq, timestamp), used for gc
+    // need UpsertRecord to add timestamps for gc
+    private List<Pair<Long, Long>> timestamps;
+
     private BinlogConfigCache binlogConfigCache;
 
     public TableBinlog(BinlogConfigCache binlogConfigCache, TBinlog binlog, long dbId, long tableId) {
         this.dbId = dbId;
         this.tableId = tableId;
+        this.binlogSize = 0;
         lock = new ReentrantReadWriteLock();
         binlogs = Sets.newTreeSet(Comparator.comparingLong(TBinlog::getCommitSeq));
+        timestamps = Lists.newArrayList();
 
         TBinlog dummy;
         if (binlog.getType() == TBinlogType.DUMMY) {
@@ -71,6 +86,10 @@ public class TableBinlog {
         if (binlog.getCommitSeq() > dummy.getCommitSeq()) {
             binlogs.add(binlog);
             ++binlog.table_ref;
+            binlogSize += BinlogUtils.getApproximateMemoryUsage(binlog);
+            if (binlog.getTimestamp() > 0) {
+                timestamps.add(Pair.of(binlog.getCommitSeq(), binlog.getTimestamp()));
+            }
         }
     }
 
@@ -79,6 +98,10 @@ public class TableBinlog {
         try {
             binlogs.add(binlog);
             ++binlog.table_ref;
+            binlogSize += BinlogUtils.getApproximateMemoryUsage(binlog);
+            if (binlog.getTimestamp() > 0) {
+                timestamps.add(Pair.of(binlog.getCommitSeq(), binlog.getTimestamp()));
+            }
         } finally {
             lock.writeLock().unlock();
         }
@@ -102,7 +125,7 @@ public class TableBinlog {
         }
     }
 
-    private Pair<TBinlog, Long> getLastUpsertAndLargestCommitSeq(long expired, BinlogComparator checker) {
+    private Pair<TBinlog, Long> getLastUpsertAndLargestCommitSeq(BinlogComparator checker) {
         if (binlogs.size() <= 1) {
             return null;
         }
@@ -113,9 +136,10 @@ public class TableBinlog {
         TBinlog lastExpiredBinlog = null;
         while (iter.hasNext()) {
             TBinlog binlog = iter.next();
-            if (checker.isExpired(binlog, expired)) {
+            if (checker.isExpired(binlog)) {
                 lastExpiredBinlog = binlog;
                 --binlog.table_ref;
+                binlogSize -= BinlogUtils.getApproximateMemoryUsage(binlog);
                 if (binlog.getType() == TBinlogType.UPSERT) {
                     tombstoneUpsert = binlog;
                 }
@@ -129,9 +153,15 @@ public class TableBinlog {
             return null;
         }
 
-        dummyBinlog.setCommitSeq(lastExpiredBinlog.getCommitSeq());
+        long expiredCommitSeq = lastExpiredBinlog.getCommitSeq();
+        dummyBinlog.setCommitSeq(expiredCommitSeq);
 
-        return Pair.of(tombstoneUpsert, lastExpiredBinlog.getCommitSeq());
+        Iterator<Pair<Long, Long>> timeIterator = timestamps.iterator();
+        while (timeIterator.hasNext() && timeIterator.next().first <= expiredCommitSeq) {
+            timeIterator.remove();
+        }
+
+        return Pair.of(tombstoneUpsert, expiredCommitSeq);
     }
 
     // this method call when db binlog enable
@@ -141,8 +171,8 @@ public class TableBinlog {
         // step 1: get tombstoneUpsertBinlog and dummyBinlog
         lock.writeLock().lock();
         try {
-            BinlogComparator check = (binlog, expire) -> binlog.getCommitSeq() <= expire;
-            tombstoneInfo = getLastUpsertAndLargestCommitSeq(expiredCommitSeq, check);
+            BinlogComparator check = (binlog) -> binlog.getCommitSeq() <= expiredCommitSeq;
+            tombstoneInfo = getLastUpsertAndLargestCommitSeq(check);
         } finally {
             lock.writeLock().unlock();
         }
@@ -165,7 +195,7 @@ public class TableBinlog {
     }
 
     // this method call when db binlog disable
-    public BinlogTombstone ttlGc() {
+    public BinlogTombstone gc() {
         // step 1: get expire time
         BinlogConfig tableBinlogConfig = binlogConfigCache.getTableBinlogConfig(dbId, tableId);
         if (tableBinlogConfig == null) {
@@ -173,19 +203,43 @@ public class TableBinlog {
         }
 
         long ttlSeconds = tableBinlogConfig.getTtlSeconds();
+        long maxBytes = tableBinlogConfig.getMaxBytes();
+        long maxHistoryNums = tableBinlogConfig.getMaxHistoryNums();
         long expiredMs = BinlogUtils.getExpiredMs(ttlSeconds);
 
-        if (expiredMs < 0) {
-            return null;
-        }
-        LOG.info("ttl gc. dbId: {}, tableId: {}, expiredMs: {}", dbId, tableId, expiredMs);
+        LOG.info(
+                "gc table binlog. dbId: {}, tableId: {}, expiredMs: {}, ttlSecond: {}, maxBytes: {}, "
+                        + "maxHistoryNums: {}, now: {}",
+                dbId, tableId, expiredMs, ttlSeconds, maxBytes, maxHistoryNums, System.currentTimeMillis());
 
         // step 2: get tombstoneUpsertBinlog and dummyBinlog
         Pair<TBinlog, Long> tombstoneInfo;
         lock.writeLock().lock();
         try {
-            BinlogComparator check = (binlog, expire) -> binlog.getTimestamp() <= expire;
-            tombstoneInfo = getLastUpsertAndLargestCommitSeq(expiredMs, check);
+            // find the last expired commit seq.
+            long expiredCommitSeq = -1;
+            Iterator<Pair<Long, Long>> timeIterator = timestamps.iterator();
+            while (timeIterator.hasNext()) {
+                Pair<Long, Long> entry = timeIterator.next();
+                if (expiredMs < entry.second) {
+                    break;
+                }
+                expiredCommitSeq = entry.first;
+            }
+
+            final long lastExpiredCommitSeq = expiredCommitSeq;
+            BinlogComparator check = (binlog) -> {
+                // NOTE: TreeSet read size during iterator remove is valid.
+                //
+                // The expired conditions in order:
+                // 1. expired time
+                // 2. the max bytes
+                // 3. the max history num
+                return binlog.getCommitSeq() <= lastExpiredCommitSeq
+                        || maxBytes < binlogSize
+                        || maxHistoryNums < binlogs.size();
+            };
+            tombstoneInfo = getLastUpsertAndLargestCommitSeq(check);
         } finally {
             lock.writeLock().unlock();
         }
@@ -210,27 +264,94 @@ public class TableBinlog {
     public void replayGc(long largestExpiredCommitSeq) {
         lock.writeLock().lock();
         try {
-            long lastSeq = -1;
-            Iterator<TBinlog> iter = binlogs.iterator();
-            TBinlog dummyBinlog = iter.next();
-
-            while (iter.hasNext()) {
-                TBinlog binlog = iter.next();
-                long commitSeq = binlog.getCommitSeq();
-                if (commitSeq <= largestExpiredCommitSeq) {
-                    lastSeq = commitSeq;
-                    --binlog.table_ref;
-                    iter.remove();
-                } else {
-                    break;
-                }
-            }
-
-            if (lastSeq != -1) {
-                dummyBinlog.setCommitSeq(lastSeq);
-            }
+            BinlogComparator checker = (binlog) -> binlog.getCommitSeq() <= largestExpiredCommitSeq;
+            getLastUpsertAndLargestCommitSeq(checker);
         } finally {
             lock.writeLock().unlock();
         }
     }
+
+    public void getBinlogInfo(Database db, BaseProcResult result) {
+        BinlogConfig binlogConfig = binlogConfigCache.getTableBinlogConfig(dbId, tableId);
+
+        String tableName = null;
+        String dropped = null;
+        if (db == null) {
+            tableName = "(dropped).(unknown)";
+            dropped = "true";
+        } else {
+            String dbName = db.getFullName();
+            Table table = db.getTableNullable(tableId);
+            if (table == null) {
+                dropped = "true";
+                tableName = dbName + ".(dropped)";
+            }
+
+            dropped = "false";
+            if (table instanceof OlapTable) {
+                OlapTable olapTable = (OlapTable) table;
+                tableName = dbName + "." + olapTable.getName();
+            } else {
+                tableName = dbName + ".(not_olaptable)";
+            }
+        }
+
+        lock.readLock().lock();
+        try {
+            List<String> info = new ArrayList<>();
+
+            info.add(tableName);
+            String type = "table";
+            info.add(type);
+
+            String id = String.valueOf(tableId);
+            info.add(id);
+            info.add(dropped);
+            String binlogLength = String.valueOf(binlogs.size());
+            info.add(binlogLength);
+            String binlogSize = String.valueOf(this.binlogSize);
+            info.add(binlogSize);
+            String firstBinlogCommittedTime = null;
+            String readableFirstBinlogCommittedTime = null;
+            for (TBinlog binlog : binlogs) {
+                long timestamp = binlog.getTimestamp();
+                if (timestamp != -1) {
+                    firstBinlogCommittedTime = String.valueOf(timestamp);
+                    readableFirstBinlogCommittedTime = BinlogUtils.convertTimeToReadable(timestamp);
+                    break;
+                }
+            }
+            info.add(firstBinlogCommittedTime);
+            info.add(readableFirstBinlogCommittedTime);
+            String lastBinlogCommittedTime = null;
+            String readableLastBinlogCommittedTime = null;
+            Iterator<TBinlog> iterator = binlogs.descendingIterator();
+            while (iterator.hasNext()) {
+                TBinlog binlog = iterator.next();
+                long timestamp = binlog.getTimestamp();
+                if (timestamp != -1) {
+                    lastBinlogCommittedTime = String.valueOf(timestamp);
+                    readableLastBinlogCommittedTime = BinlogUtils.convertTimeToReadable(timestamp);
+                    break;
+                }
+            }
+            info.add(lastBinlogCommittedTime);
+            info.add(readableLastBinlogCommittedTime);
+            String binlogTtlSeconds = null;
+            String binlogMaxBytes = null;
+            String binlogMaxHistoryNums = null;
+            if (binlogConfig != null) {
+                binlogTtlSeconds = String.valueOf(binlogConfig.getTtlSeconds());
+                binlogMaxBytes = String.valueOf(binlogConfig.getMaxBytes());
+                binlogMaxHistoryNums = String.valueOf(binlogConfig.getMaxHistoryNums());
+            }
+            info.add(binlogTtlSeconds);
+            info.add(binlogMaxBytes);
+            info.add(binlogMaxHistoryNums);
+
+            result.addRow(info);
+        } finally {
+            lock.readLock().unlock();
+        }
+    }
 }
