@@ -243,7 +243,7 @@ public class Column implements Writable, GsonPostProcessable {
         this.children = column.getChildren();
         this.uniqueId = column.getUniqueId();
         this.defineExpr = column.getDefineExpr();
-        this.defineName = column.getDefineName();
+        this.defineName = column.getRealDefineName();
     }
 
     public void createChildrenColumn(Type type, Column column) {
@@ -287,6 +287,12 @@ public class Column implements Writable, GsonPostProcessable {
         return name;
     }
 
+    // In order for the copy constructor to get the real defineName value.
+    // getDefineName() cannot meet this requirement
+    public String getRealDefineName() {
+        return defineName;
+    }
+
     public void setName(String newName) {
         this.name = newName;
     }
