@@ -27,6 +27,7 @@ import org.apache.doris.persist.OperationType;
 import org.apache.doris.persist.gson.GsonUtils;
 import org.apache.doris.thrift.TCompressionType;
 import org.apache.doris.thrift.TStorageFormat;
+import org.apache.doris.thrift.TStorageMedium;
 
 import com.google.common.base.Strings;
 import com.google.common.collect.Maps;
@@ -64,6 +65,8 @@ public class TableProperty implements Writable {
     private BinlogConfig binlogConfig;
     private boolean isDynamicSchema = false;
 
+    private TStorageMedium storageMedium = null;
+
     /*
      * the default storage format of this table.
      * DEFAULT: depends on BE's config 'default_rowset_type'
@@ -128,6 +131,7 @@ public class TableProperty implements Writable {
                 break;
             case OperationType.OP_MODIFY_IN_MEMORY:
                 buildInMemory();
+                buildStorageMedium();
                 buildStoragePolicy();
                 buildIsBeingSynced();
                 buildCompactionPolicy();
@@ -306,6 +310,20 @@ public class TableProperty implements Writable {
         return timeSeriesCompactionLevelThreshold;
     }
 
+    public TableProperty buildStorageMedium() {
+        String storageMediumStr = properties.get(PropertyAnalyzer.PROPERTIES_STORAGE_MEDIUM);
+        if (Strings.isNullOrEmpty(storageMediumStr)) {
+            storageMedium = null;
+        } else {
+            storageMedium = TStorageMedium.valueOf(storageMediumStr);
+        }
+        return this;
+    }
+
+    public TStorageMedium getStorageMedium() {
+        return storageMedium;
+    }
+
     public TableProperty buildStoragePolicy() {
         storagePolicy = properties.getOrDefault(PropertyAnalyzer.PROPERTIES_STORAGE_POLICY, "");
         return this;
@@ -529,6 +547,7 @@ public class TableProperty implements Writable {
                 .executeBuildDynamicProperty()
                 .buildInMemory()
                 .buildDynamicSchema()
+                .buildStorageMedium()
                 .buildStorageFormat()
                 .buildDataSortInfo()
                 .buildCompressionType()
