@@ -26,7 +26,6 @@ import com.google.common.base.Joiner;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import com.google.gson.Gson;
-
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 
@@ -86,6 +85,10 @@ public class KafkaProgress extends RoutineLoadProgress {
         return partitionIdToOffset.get(kafkaPartition);
     }
 
+    public Map<Integer, Long> getOffsetByPartition() {
+        return partitionIdToOffset;
+    }
+
     public boolean containsPartition(Integer kafkaPartition) {
         return partitionIdToOffset.containsKey(kafkaPartition);
     }
@@ -133,17 +136,17 @@ public class KafkaProgress extends RoutineLoadProgress {
         List<Pair<Integer, String>> pairs = Lists.newArrayList();
         for (Map.Entry<Integer, Long> entry : partitionIdToOffset.entrySet()) {
             if (entry.getValue() == 0) {
-                pairs.add(Pair.create(entry.getKey(), OFFSET_ZERO));
+                pairs.add(Pair.of(entry.getKey(), OFFSET_ZERO));
             } else if (entry.getValue() == -1) {
-                pairs.add(Pair.create(entry.getKey(), OFFSET_END));
+                pairs.add(Pair.of(entry.getKey(), OFFSET_END));
             } else if (entry.getValue() == -2) {
-                pairs.add(Pair.create(entry.getKey(), OFFSET_BEGINNING));
+                pairs.add(Pair.of(entry.getKey(), OFFSET_BEGINNING));
             } else {
                 long offset = entry.getValue();
                 if (alreadyConsumed) {
                     offset -= 1;
                 }
-                pairs.add(Pair.create(entry.getKey(), "" + offset));
+                pairs.add(Pair.of(entry.getKey(), "" + offset));
             }
         }
         return pairs;
