@@ -230,6 +230,12 @@ public class TransactionState implements Writable {
 
     private long lastPublishVersionTime = -1;
 
+    private long publishCount = 0;
+
+    // txn may try finish many times and generate a lot of log.
+    // use lastPublishLogTime to reduce log.
+    private long lastPublishLogTime = 0;
+
     @SerializedName(value = "callbackId")
     private long callbackId = -1;
 
@@ -347,6 +353,7 @@ public class TransactionState implements Writable {
     }
 
     public void updateSendTaskTime() {
+        this.publishCount++;
         this.lastPublishVersionTime = System.currentTimeMillis();
         if (this.firstPublishVersionTime <= 0) {
             this.firstPublishVersionTime = lastPublishVersionTime;
@@ -361,6 +368,10 @@ public class TransactionState implements Writable {
         return this.lastPublishVersionTime;
     }
 
+    public long getPublishCount() {
+        return publishCount;
+    }
+
     public boolean hasSendTask() {
         return this.hasSendTask;
     }
@@ -429,6 +440,14 @@ public class TransactionState implements Writable {
         return errorLogUrl;
     }
 
+    public long getLastPublishLogTime() {
+        return lastPublishLogTime;
+    }
+
+    public void setLastPublishLogTime(long lastPublishLogTime) {
+        this.lastPublishLogTime = lastPublishLogTime;
+    }
+
     public void setTransactionStatus(TransactionStatus transactionStatus) {
         // status changed
         this.preStatus = this.transactionStatus;
