@@ -337,7 +337,7 @@ public class CreateTableStmtTest {
                                         null, null, "");
         expectedEx.expect(AnalysisException.class);
         expectedEx.expectMessage(
-                "Aggregate type `col3` hll NONE NOT NULL COMMENT \"\" is not compatible with primitive type hll");
+                "Aggregate type `col3` HLL NONE NOT NULL COMMENT \"\" is not compatible with primitive type HLL");
         stmt.analyze(analyzer);
     }
 
@@ -419,8 +419,8 @@ public class CreateTableStmtTest {
         stmt.analyze(analyzer);
 
         Assert.assertEquals(
-                "CREATE EXTERNAL TABLE `testCluster:db1`.`table1` (\n" + "  `id` int(11) NOT NULL COMMENT \"\",\n"
-                        + "  `name` int(11) NULL COMMENT \"\"\n" + ") ENGINE = hudi\n"
+                "CREATE EXTERNAL TABLE `testCluster:db1`.`table1` (\n" + "  `id` INT NOT NULL COMMENT \"\",\n"
+                        + "  `name` INT NULL COMMENT \"\"\n" + ") ENGINE = hudi\n"
                         + "PROPERTIES (\"hudi.database\"  =  \"doris\",\n"
                         + "\"hudi.hive.metastore.uris\"  =  \"thrift://127.0.0.1:9087\",\n"
                         + "\"hudi.table\"  =  \"test\")", stmt.toString());
@@ -455,8 +455,8 @@ public class CreateTableStmtTest {
                 properties, null, "", null);
 
         String createTableSql = "CREATE TABLE IF NOT EXISTS `demo`.`testTosql1` (\n"
-                + "  `a` bigint(20) NOT NULL COMMENT \"\",\n"
-                + "  `b` int(11) NOT NULL COMMENT \"\"\n"
+                + "  `a` BIGINT NOT NULL COMMENT \"\",\n"
+                + "  `b` INT NOT NULL COMMENT \"\"\n"
                 + ") ENGINE = olap\n"
                 + "AGGREGATE KEY(`a`)\n"
                 + "PROPERTIES (\"replication_num\"  =  \"1\")";
@@ -484,14 +484,14 @@ public class CreateTableStmtTest {
                 tableName, columnDefs, engineName, keysDesc, null, null,
                 properties, null, "", null);
         createTableSql = "CREATE TABLE `demo`.`testTosql2` (\n"
-                + "  `a` bigint(20) NOT NULL COMMENT \"\",\n"
-                + "  `b` int(11) NOT NULL COMMENT \"\",\n"
-                + "  `c` text NULL COMMENT \"\",\n"
-                + "  `d` double NULL COMMENT \"\",\n"
-                + "  `e` decimalv3(38, 0) NOT NULL COMMENT \"\",\n"
-                + "  `f` date NOT NULL COMMENT \"\",\n"
-                + "  `g` smallint(6) NOT NULL COMMENT \"\",\n"
-                + "  `h` boolean NOT NULL COMMENT \"\"\n"
+                + "  `a` BIGINT NOT NULL COMMENT \"\",\n"
+                + "  `b` INT NOT NULL COMMENT \"\",\n"
+                + "  `c` TEXT NULL COMMENT \"\",\n"
+                + "  `d` DOUBLE NULL COMMENT \"\",\n"
+                + "  `e` DECIMALV3(38, 0) NOT NULL COMMENT \"\",\n"
+                + "  `f` DATE NOT NULL COMMENT \"\",\n"
+                + "  `g` SMALLINT NOT NULL COMMENT \"\",\n"
+                + "  `h` BOOLEAN NOT NULL COMMENT \"\"\n"
                 + ") ENGINE = olap\n"
                 + "DUPLICATE KEY(`a`, `d`, `f`)\n"
                 + "PROPERTIES (\"replication_num\"  =  \"10\")";
